REVAPI <- "http://https://api.pdok.nl/bzk/locatieserver/search/v3_1/reverse/"

#' experimental reverse api
nl_reverse <- function(){
  stop("Not working yet")
}
